@@ -1,12 +1,11 @@
 """ Dustmaker explicit public exports. This is not the extent of the public
 API, merely a convenience for accessing the most commonly used parts.
 """
-from .level import Level
+from .dfreader import DFReader, read_level
+from .dfwriter import DFWriter, write_level
 from .entity import Entity
-from .prop import Prop
-from .variable import Variable
 from .exceptions import LevelException, LevelParseException
+from .level import Level
+from .prop import Prop
 from .tile import Tile
-
-from .dfreader import read_level, DFReader
-from .dfwriter import write_level, DFWriter
+from .variable import Variable
