@@ -3,6 +3,7 @@
 import argparse
 import sys
 
+from dustmaker.cmd.save_convert import SaveConvert
 from dustmaker.cmd.thumbnail import Thumbnail
 from dustmaker.cmd.transform import Transform
 from dustmaker.cmd.variables import Variables
@@ -11,6 +12,7 @@ UTILITIES = (
     Thumbnail,
     Transform,
     Variables,
+    SaveConvert,
 )
 
 
